@@ -6,20 +6,21 @@ no warnings qw(void once uninitialized numeric);
 package Moops::Keyword;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.020';
+our $VERSION   = '0.021';
 
 use Moo;
 use B qw(perlstring);
 use Module::Runtime qw(module_notional_filename use_package_optimistically);
 use namespace::sweep;
 
-has 'keyword'    => (is => 'ro');
-has 'ccstash'    => (is => 'ro');
-has 'package'    => (is => 'ro');
-has 'version'    => (is => 'ro', predicate => 'has_version');
-has 'relations'  => (is => 'ro');
-has 'is_empty'   => (is => 'ro');
-has 'imports'    => (is => 'ro', predicate => 'has_imports');
+has 'keyword'        => (is => 'ro');
+has 'ccstash'        => (is => 'ro');
+has 'package'        => (is => 'ro');
+has 'version'        => (is => 'ro', predicate => 'has_version');
+has 'relations'      => (is => 'ro');
+has 'is_empty'       => (is => 'ro');
+has 'imports'        => (is => 'ro', predicate => 'has_imports');
+has 'version_checks' => (is => 'ro');
 
 sub BUILD
 {
@@ -126,4 +127,18 @@ sub qualify_relationship
 	1;
 }
 
+sub version_relationship
+{
+	1;
+}
+
+sub check_prerequisites
+{
+	my $self = shift;
+	for my $prereq (@{$self->version_checks})
+	{
+		&use_package_optimistically(@$prereq) if defined $prereq->[1];
+	}
+}
+
 1;
